summaryrefslogtreecommitdiffstats
path: root/src/include/eiotas_spin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/eiotas_spin.h')
-rw-r--r--src/include/eiotas_spin.h57
1 files changed, 40 insertions, 17 deletions
diff --git a/src/include/eiotas_spin.h b/src/include/eiotas_spin.h
index 3854878..08742e4 100644
--- a/src/include/eiotas_spin.h
+++ b/src/include/eiotas_spin.h
@@ -28,28 +28,37 @@
/**
* @typedef Eiotas_Spin
* Type for a Spin, the top level Room which holds Eiotas_Particle fifos and free Eiotas_Particles.
*/
typedef struct _Eiotas_Spin Eiotas_Spin;
/**
* @struct _Eiotas_Spin
* Struct for a Spin, the top level Room which holds Eiotas_Particle fifos and free Eiotas_Particles.
*/
struct _Eiotas_Spin {
Eiotas_Room room; /**< higher level Room */
- Eina_Array *free_particles; /**< lifo of free to reuse Eiotas_Particles TODO support different particle types, use an Eina_Hash */
+ Eina_Array *free_particles; /**< lifo of free to reuse @ref Eiotas_Particle TODO support different particle types, use an Eina_Hash */
Eina_Inlist *app_fifo; /**< fifo of application priority particles */
Eina_Inlist *sys_fifo; /**< fifo of system priority particles */
};
/**
+ * @defgroup Eiotas_Spin Eiotas_Spin
+ *
+ * A Eiota_Spin is the top level object. It holds @ref Eiotas_Particle free list,
+ * @ref Eiotas_Particle system and application fifos.
+ *
+ * @{
+ */
+
+/**
* @brief Free allocated resources.
*
* @param spin The Eiotas_Spin to free.
*
* This function will free all it's child Iotas,
* all the Eiotas_Particles holded in app_fifo, sys_fifo and free_particles.
*/
EAPI void eiotas_spin_free(Eiotas_Spin *spin);
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
* @param name The name of this spin.
* @param step The count of pointers to add when increasing the fifo size.
*
* @return the new allocated Eiotas_Spin @c NULL on failure
*
* @see eina_array_new().
*/
EAPI Eiotas_Spin* eiotas_spin_add(const char* name, unsigned int step);
/**
* @brief Require a Eiotas_Particle from the free list.
*
* @param spin The Eiotas_Spin to require a Eiotas_Particle from.
*
* @return a ready to use Eiotas_Particle
*
* This function will allocate and initialize a new Eiotas_Particle if there is none in the free list.
*/
EAPI Eiotas_Particle* eiotas_spin_require_particle(Eiotas_Spin *spin);
/**
* @brief Release a particle.
*
* @param spin The Eiotas_Spin to restore the particle to.
* @param particle The Eiotas_Particle to be restored.
*
* This function calls eiotas_particle_reset() before giving back the Eiotas_Particle.
* Each Eiotas_Particle merged in the first one are also released.
*
* @see eiotas_particle_reset().
*/
EAPI void eiotas_spin_release_particle(Eiotas_Spin *spin, Eiotas_Particle *particle);
/**
* @brief Appand the Eiotas_Particle to the app or sys fifo.
*
* @param spin The Eiotas_Spin to post the particle to.
* @param particle The Eiotas_Particle to be sent.
* @param system Post to the system fifo us true, otherwise to the application fifo.
*
*/
EAPI void eiotas_spin_send_particle(Eiotas_Spin *spin, Eiotas_Particle *particle, Eina_Bool system);
+/**
+ * @brief Require a @ref Eiotas_Particle from the free list.
+ *
+ * @see eiotas_spin_require_particle
+ */
#define eiotas_require_particle(_iota) eiotas_spin_require_particle((Eiotas_Spin*)((Eiotas_Iota*)(_iota))->spin)
+/**
+ * @brief Release a particle.
+ *
+ * @see eiotas_spin_release_particle
+ */
#define eiotas_release_particle(_iota,_particle) eiotas_spin_release_particle((Eiotas_Spin*)((Eiotas_Iota*)(_iota))->spin,_particle)
+/**
+ * @}
+ */
+
#endif // __EIOTAS_SPIN_H__
@@ -28,28 +28,37 @@
/**
* @typedef Eiotas_Spin
- * Type for a Spin, the top level Room which holds Eiotas_Particle fifos and free Eiotas_Particles.
+ * Type for a Spin, the top level Room which holds @ref Eiotas_Particle fifos and free @ref Eiotas_Particle.
*/
typedef struct _Eiotas_Spin Eiotas_Spin;
@@ -28,28 +28,37 @@
/**
* @struct _Eiotas_Spin
- * Struct for a Spin, the top level Room which holds Eiotas_Particle fifos and free Eiotas_Particles.
+ * Struct for a Spin, the top level Room which holds @ref Eiotas_Particle fifos and free @ref Eiotas_Particle.
*/
struct _Eiotas_Spin {
@@ -28,28 +28,37 @@
* @brief Free allocated resources.
*
- * @param spin The Eiotas_Spin to free.
+ * @param spin The @ref Eiotas_Spin to free.
*
* This function will free all it's child Iotas,
@@ -28,28 +28,37 @@
*
* This function will free all it's child Iotas,
- * all the Eiotas_Particles holded in app_fifo, sys_fifo and free_particles.
+ * all the @ref Eiotas_Particle holded in app_fifo, sys_fifo and free_particles.
*/
EAPI void eiotas_spin_free(Eiotas_Spin *spin);
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
* @param step The count of pointers to add when increasing the fifo size.
*
- * @return the new allocated Eiotas_Spin @c NULL on failure
+ * @return the new allocated @ref Eiotas_Spin @c NULL on failure
*
* @see eina_array_new().
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
EAPI Eiotas_Spin* eiotas_spin_add(const char* name, unsigned int step);
/**
- * @brief Require a Eiotas_Particle from the free list.
+ * @brief Require a @ref Eiotas_Particle from the free list.
*
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
*
- * @param spin The Eiotas_Spin to require a Eiotas_Particle from.
+ * @param spin The @ref Eiotas_Spin to require a @ref Eiotas_Particle from.
*
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
*
- * @return a ready to use Eiotas_Particle
+ * @return a ready to use @ref Eiotas_Particle
*
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
*
- * This function will allocate and initialize a new Eiotas_Particle if there is none in the free list.
+ * This function will allocate and initialize a new @ref Eiotas_Particle if there is none in the free list.
*/
EAPI Eiotas_Particle* eiotas_spin_require_particle(Eiotas_Spin *spin);
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
* @brief Release a particle.
*
- * @param spin The Eiotas_Spin to restore the particle to.
- * @param particle The Eiotas_Particle to be restored.
+ * @param spin The @ref Eiotas_Spin to restore the particle to.
+ * @param particle The @ref Eiotas_Particle to be restored.
*
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
*
- * This function calls eiotas_particle_reset() before giving back the Eiotas_Particle.
- * Each Eiotas_Particle merged in the first one are also released.
+ * This function calls eiotas_particle_reset() before giving back the @ref Eiotas_Particle.
+ * Each @ref Eiotas_Particle merged in the first one are also released.
*
* @see eiotas_particle_reset().
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
EAPI void eiotas_spin_release_particle(Eiotas_Spin *spin, Eiotas_Particle *particle);
/**
- * @brief Appand the Eiotas_Particle to the app or sys fifo.
+ * @brief Append the @ref Eiotas_Particle to the app or sys fifo.
*
@@ -59,48 +68,62 @@ EAPI void eiotas_spin_free(Eiotas_Spin *spin);
*
- * @param spin The Eiotas_Spin to post the particle to.
- * @param particle The Eiotas_Particle to be sent.
+ * @param spin The @ref Eiotas_Spin to post the particle to.
+ * @param particle The @ref Eiotas_Particle to be sent.
* @param system Post to the system fifo us true, otherwise to the application fifo.
*